@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_client_types_h =
- *   "$Id: client-types.h 6716 2007-06-27 18:57:31Z akirschbaum $";
+ *   "$Id$";
  */
 /*
     Crossfire client, a client program for the crossfire program.
@@ -55,6 +55,14 @@
 #  include <fcntl.h>
 #endif
 
+#ifdef WIN32
+#  include <winsock2.h>
+#endif
+
+#ifdef HAVE_PTHREAD_H
+#  include <pthread.h>
+#endif
+
 /* Just some handy ones I like to use */
 #ifndef FALSE
 #define FALSE 0
@@ -102,8 +110,15 @@ typedef signed char       sint8;
 #define FMT64               "I64d"
 #define FMT64U              "I64u"
 
+/* mingw defines rand and srand only */
+#ifndef random
+#define random rand
+#endif
+#ifndef srandom
+#define srandom srand
 #endif
 
+#endif
 
 #ifndef SOL_TCP
 #define SOL_TCP IPPROTO_TCP
