@@ -1,5 +1,5 @@
-const char *rcsid_common_client_c =
-    "$Id: client.c 8264 2008-01-25 01:56:33Z kbulgrien $";
+const char * const rcsid_common_client_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -56,10 +56,14 @@ char *server=SERVER;
 char *server=NULL;
 #endif
 
+char VERSION_INFO[256];
+
 char *client_libdir=NULL,*meta_server=META_SERVER;
 char *sound_server="cfsndserv";
 char *skill_names[MAX_SKILL];
 
+int last_used_skills[MAX_SKILL+1];
+
 int meta_port=META_PORT, want_skill_exp=0,
     replyinfo_status=0, requestinfo_sent=0, replyinfo_last_face=0,
     maxfd,metaserver_on=METASERVER, metaserver2_on=METASERVER2;
@@ -118,6 +122,8 @@ struct CmdMapping commands[] = {
 
 
     { "sound", SoundCmd, MIXED /* int8, int8, int16, int8 */},
+    { "sound2", Sound2Cmd, MIXED /* int8, int8, int8, int8, int8, int8, chars, int8, chars */},
+    { "music", (CmdProc)MusicCmd, ASCII },
     { "anim", AnimCmd, SHORT_ARRAY},
     { "smooth", SmoothCmd, SHORT_ARRAY},
 
@@ -134,6 +140,8 @@ struct CmdMapping commands[] = {
     { "query", (CmdProc)handle_query, ASCII},
     { "replyinfo", ReplyInfoCmd, ASCII},
     { "ExtendedTextSet", (CmdProc)SinkCmd, NODATA},
+
+    { "pickup", PickupCmd, INT_ARRAY /* uint32 */},
 };
 
 #define NCOMMANDS ((int)(sizeof(commands)/sizeof(struct CmdMapping)))
@@ -371,8 +379,8 @@ void negotiate_connection(int sound)
      */
     if (face_info.want_faceset) face_info.faceset = atoi(face_info.want_faceset);
     cs_print_string(csocket.fd,
-	    "setup map2cmd 1 tick 1 sound %d sexp %d darkness %d newmapcmd 1 spellmon 1 faceset %d facecache %d exp64 1 itemcmd 2",
-	    sound>=0, want_skill_exp,
+	    "setup map2cmd 1 tick 1 sound %d%s sexp %d darkness %d newmapcmd 1 spellmon 1 faceset %d facecache %d exp64 1 itemcmd 2",
+	    sound>=0, (sound>=0) ? " sound2 3" : "", want_skill_exp,
 		    want_config[CONFIG_LIGHTING]?1:0, face_info.faceset,
 		    want_config[CONFIG_CACHE]);
 
@@ -391,6 +399,7 @@ void negotiate_connection(int sound)
         /*will handle all special infos requested when setup answer this command*/
     }
     cs_print_string(csocket.fd,"setup extendedTextInfos 1");
+    cs_print_string(csocket.fd,"setup want_pickup 1");
     cs_print_string(csocket.fd,"setup inscribe 1");
 
     /* If the server will answer the requestinfo for image_info and image_data,
@@ -462,7 +471,7 @@ void negotiate_connection(int sound)
     if (use_config[CONFIG_DOWNLOAD]) {
 	char buf[MAX_BUF];
 
-	sprintf(buf,"Download of images complete.  Found %d locally, downloaded %d from server\n",
+	snprintf(buf, sizeof(buf), "Download of images complete.  Found %d locally, downloaded %d from server\n",
 		face_info.cache_hits, face_info.cache_misses);
 	draw_info(buf, NDI_GOLD);
     }
