@@ -1,11 +1,11 @@
 /*
  * static char *rcsid_client_h =
- *   "$Id: client.h 7552 2007-11-20 20:44:54Z tchize $";
+ *   "$Id$";
  */
 /*
     Crossfire client, a client program for the crossfire program.
 
-    Copyright (C) 2001 Mark Wedel & Crossfire Development Team
+    Copyright (C) 2001,2007 Mark Wedel & Crossfire Development Team
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,9 +24,11 @@
     The author can be reached via e-mail to crossfire-devel@real-time.com
 */
 
-/* This file includes the various dependencies header files needed
- * by most everything.  It also declares structures and other variables
- * that the gui portion needs
+/**
+ * @file client.h
+ * This file includes the various dependencies header files needed by most
+ * everything.  It also declares structures and other variables that the GUI
+ * portion needs
  */
 
 #include <config.h>
@@ -42,9 +44,9 @@
 #define MULTKEYS
 
 #define VERSION_CS 1023
-#define VERSION_SC 1027
+#define VERSION_SC 1029
 
-char VERSION_INFO[256];
+extern char VERSION_INFO[256];
 
 /* Don't send more than this many outstanding commands to the server
  * this is only a default value.
@@ -69,12 +71,13 @@ char VERSION_INFO[256];
 typedef struct Animations {
     uint16  flags;
     uint8   num_animations; /* number of animations.  Value of 2 means
-			     * only faces[0],[1] have meaningfull values.
-			     */
-    uint16  *faces;
+                             * only faces[0],[1] have meaningfull values.
+                             */
     uint8   speed;
     uint8   speed_left;
     uint8   phase;
+    uint16  *faces;
+
 } Animations;
 
 extern Animations animations[MAXANIM];
@@ -192,124 +195,145 @@ typedef enum rangetype {
 #define CFG_DM_SDL	    1
 #define CFG_DM_OPENGL	    2
 
-
-
 extern sint16 want_config[CONFIG_NUMS], use_config[CONFIG_NUMS];
-/* see common/init.c - basically, this is a string to number
- * mapping that is used when loading/saving the values.
- */
-extern const char *const config_names[CONFIG_NUMS];
-
 
+extern const char *const config_names[CONFIG_NUMS]; /**< See common/init.c -
+                                         * basically, this is a string to
+                                         * number mapping that is used when
+                                         * loading/saving the values.
+                                         */
 typedef struct Stat_struct {
-    sint8 Str,Dex,Con,Wis,Cha,Int,Pow;
-    sint8 wc,ac;	    /* Weapon Class and Armour Class */
-    sint8 level;
-    sint16 hp;		    /* Hit Points. */
-    sint16 maxhp;
-    sint16 sp;		    /* Spell points.  Used to cast spells. */
-    sint16 maxsp;	    /* Max spell points. */
-    sint16 grace;	    /* Spell points.  Used to cast spells. */
-    sint16 maxgrace;	    /* Max spell points. */
-    sint64 exp;		    /* Experience.  Killers gain 1/10. */
-    sint16 food;	    /* How much food in stomach.  0 = starved. */
-    sint16 dam;		    /* How much damage this object does when hitting */
-    sint32 speed;	    /* Gets converted to a float for display*/
-    sint32 weapon_sp;	    /* Gets converted to a float for display */
-    uint32 attuned;         /* The spell paths to which the player is attuned */
-    uint32 repelled;        /* The spell paths to which the player is repelled */
-    uint32 denied;          /* The spell paths denied to the player*/
-    uint16 flags;	    /* contains fire on/run on flags */
-    sint16 resists[30];	    /* Resistant values */
-    uint32 resist_change:1; /* Resistant value has changed */
-    sint16 skill_level[MAX_SKILL];  /* Level and experience totals for */
-    sint64 skill_exp[MAX_SKILL];    /* skills */
-    uint32 weight_limit;    /* weight limit */
+    sint8 Str;                          /**< Strength */
+    sint8 Dex;                          /**< Dexterity */
+    sint8 Con;                          /**< Constitution */
+    sint8 Wis;                          /**< Wisdom */
+    sint8 Cha;                          /**< Charisma */
+    sint8 Int;                          /**< Intelligence */
+    sint8 Pow;                          /**< Power */
+    sint8 wc;                           /**< Weapon Class */
+    sint8 ac;                           /**< Armour Class */
+    sint8 level;                        /**< Experience level */
+    sint16 hp;                          /**< Hit Points */
+    sint16 maxhp;                       /**< Maximum hit points */
+    sint16 sp;                          /**< Spell points for casting spells */
+    sint16 maxsp;                       /**< Maximum spell points. */
+    sint16 grace;                       /**< Spell points for using prayers. */
+    sint16 maxgrace;                    /**< Maximum spell points. */
+    sint64 exp;                         /**< Experience.  Killers gain 1/10. */
+    sint16 food;                        /**< Quantity food in stomach.
+                                         *   0 = starved.
+                                         */
+    sint16 dam;                         /**< How much damage this object does
+                                         *   for each hit
+                                         */
+    sint32 speed;                       /**< Speed (is displayed as a float) */
+    sint32 weapon_sp;                   /**< Weapon speed (displayed in client
+                                         *   as a float)
+                                         */
+    uint32 attuned;                     /**< Spell paths to which the player is
+                                         *   attuned
+                                         */
+    uint32 repelled;                    /**< Spell paths to which the player is
+                                         *   repelled
+                                         */
+    uint32 denied;                      /**< Spell paths denied to the player*/
+    uint16 flags;                       /**< Contains fire on/run on flags */
+    sint16 resists[30];                 /**< Resistant values */
+    uint32 resist_change:1;             /**< Resistant value change flag */
+    sint16 skill_level[MAX_SKILL];      /**< Level of known skills */
+    sint64 skill_exp[MAX_SKILL];        /**< Experience points for skills */
+    uint32 weight_limit;                /**< Carrying weight limit */
 } Stats;
 
-
 typedef struct Spell_struct {
     struct Spell_struct *next;
-    char name[256]; /* the protocol allows one length bit, so 256 is the maximum name length */
-    char message[10000]; /* this is plenty, the packets can't be much bigger than this anyway */
-    uint32 tag; /* used to identify the spell by updspell */
-    uint16 level;
-    uint16 time; /* number of ticks to cast */
-    uint16 sp;
-    uint16 grace;
-    uint16 dam;
-    uint8 skill_number; /* the index in the skill arrays, plus CS_STAT_SKILLINFO */
-    char *skill; /* pointer to the skill name, derived from the skill number */
-    uint32 path; /* the bitmask of paths this spell belongs to */
-    sint32 face;
+    char name[256];                     /**< The protocol allows one length
+                                         *   bit, so 256 is the maximum name
+                                         *   length */
+    char message[10000];                /**< This is plenty, the packets can't
+                                         *   be much bigger than this anyway */
+    uint32 tag;                         /**< Used to identify the spell by
+                                         *   updspell */
+    uint16 level;                       /**<  */
+    uint16 time;                        /**< number of ticks to cast */
+    uint16 sp;                          /**<  */
+    uint16 grace;                       /**<  */
+    uint16 dam;                         /**<  */
+    uint8 skill_number;                 /**< The index in the skill arrays,
+                                         *   plus CS_STAT_SKILLINFO */
+    char *skill;                        /**< Pointer to the skill name, derived
+                                         *   from the skill number */
+    uint32 path;                        /**< The bitmask of paths this spell
+                                         * belongs to */
+    sint32 face;                        /**<  */
 } Spell;
 
 typedef struct Player_Struct {
-    item	*ob;		/* Player object */
-    item	*below;		/* Items below the player (pl.below->inv) */
-    item	*container;	/* open container */
-    uint16	count_left;	/* count for commands */
-    Input_State input_state;	/* What the input state is */
-    char	last_command[MAX_BUF];	/* Last command entered */
-    char	input_text[MAX_BUF];	/* keys typed (for long commands) */
-    item	*ranges[range_size];	/* Object that is used for that */
-				/* range type */
-    uint8	ready_spell;	/* Index to spell that is readied */
-    char	spells[255][40];	/* List of all the spells the */
-				/* player knows */
-    Stats	stats;		/* Player stats */
-    Spell	*spelldata;	/* linked list of spells known to the player */
-    char	title[MAX_BUF];	/* Title of character */
-    char	range[MAX_BUF];	/* Range attack chosen */
-    uint32	spells_updated; /* tracks whether the spells updated*/
-    uint32	fire_on:1;	/* True if fire key is pressed */
-    uint32	run_on:1;	/* True if run key is on */
-    uint32	meta_on:1;	/* True if fire key is pressed */
-    uint32	alt_on:1;	/* True if fire key is pressed */
-    uint32	no_echo:1;	/* If TRUE, don't echo keystrokes */
-    uint32	count;		/* Repeat count on command */
-    uint16	mmapx, mmapy;	/* size of magic map */
-    uint16	pmapx, pmapy;	/* Where the player is on the magic map */
-    uint8	*magicmap;	/* Magic map data */
-    uint8	showmagic;	/* If 0, show normal map, otherwise, show
-				 * magic map.
-				 */
-    uint16	mapxres,mapyres;/* Resolution to draw on the magic map
-                                 * Only used in client-specific code, so it should move there. */
-
+    item        *ob;                    /**< Player object */
+    item        *below;                 /**< Items below the player
+                                         *   (pl.below->inv) */
+    item        *container;             /**< open container */
+    uint16      count_left;             /**< count for commands */
+    Input_State input_state;            /**< What the input state is */
+    char        last_command[MAX_BUF];  /**< Last command entered */
+    char        input_text[MAX_BUF];    /**< keys typed (for long commands) */
+    item        *ranges[range_size];    /**< Object that is used for that */
+                                        /**< range type */
+    uint8       ready_spell;            /**< Index to spell that is readied */
+    char        spells[255][40];        /**< List of all the spells the */
+                                        /**< player knows */
+    Stats       stats;                  /**< Player stats */
+    Spell       *spelldata;             /**< List of spells known */
+    char        title[MAX_BUF];         /**< Title of character */
+    char        range[MAX_BUF];         /**< Range attack chosen */
+    uint32      spells_updated;         /**< Whether or not spells updated */
+    uint32      fire_on:1;              /**< True if fire key is pressed */
+    uint32      run_on:1;               /**< True if run key is on */
+    uint32      meta_on:1;              /**< True if fire key is pressed */
+    uint32      alt_on:1;               /**< True if fire key is pressed */
+    uint32      no_echo:1;              /**< If TRUE, don't echo keystrokes */
+    uint32      count;                  /**< Repeat count on command */
+    uint16      mmapx, mmapy;           /**< size of magic map */
+    uint16      pmapx, pmapy;           /**< Where the player is on the magic
+                                         *   map */
+    uint8       *magicmap;              /**< Magic map data */
+    uint8       showmagic;              /**< If 0, show the normal map,
+                                         *   otherwise show the magic map. */
+    uint16      mapxres,mapyres;        /**< Resolution to draw on the magic
+                                         *   map. Only used in client-specific
+                                         *   code, so it should move there. */
 #ifdef MULTKEYS
-    char    name[ 40 ]; /* Player's name, for player-specific key files */
+    char    name[ 40 ];                 /**< Player's name, for player-specific
+                                         *   key files */
 #endif
 } Client_Player;
 
-
 /* This faceset information is pretty much grabbed right from
  * server/socket/image.c
  */
 
 #define MAX_FACE_SETS   20
-
-/* Max size of image in each direction.  This
- * is needed for the x11 client, which wants to
- * initalize some data once.  Increasing this would
- * likely only need a bigger footrpint
- */
-#define MAX_IMAGE_SIZE 320
-typedef struct {
-    uint8   setnum;
-    char    *prefix;
-    char    *fullname;
-    uint8   fallback;
-    char    *size;
-    char    *extension;
-    char    *comment;
+#define MAX_IMAGE_SIZE 320              /**< Maximum size of image in each
+                                         *   direction.  This is needed for the
+                                         *   x11 client, which wants to
+                                         *   initalize some data once.
+                                         *   Increasing this would  likely only
+                                         *    need a bigger footprint
+                                         */
+typedef struct FaceSets_struct {
+    uint8   setnum;                     /**<  */
+    uint8   fallback;                   /**<  */
+    char    *prefix;                    /**<  */
+    char    *fullname;                  /**<  */
+    char    *size;                      /**<  */
+    char    *extension;                 /**<  */
+    char    *comment;                   /**<  */
 } FaceSets;
 
-
 /* Make one struct that holds most of the image related data.
  * reduces danger of namespace collision.
  */
-typedef struct {
+typedef struct Face_Information_struct {
     uint8   faceset;
     char    *want_faceset;
     sint16  num_images;
@@ -331,12 +355,14 @@ extern Face_Information face_info;
 extern Client_Player cpl;		/* Player object. */
 extern char *skill_names[MAX_SKILL];
 
+extern int last_used_skills[MAX_SKILL+1]; // maps position to skill id with trailing zero as stop mark
+
 
 typedef enum LogLevel {
   LOG_DEBUG = 0, LOG_INFO = 1, LOG_WARNING = 2, LOG_ERROR = 3, LOG_CRITICAL = 4
 } LogLevel;
 
-typedef struct LogEntry{
+typedef struct LogEntry {
     char* message;
     char* origin;
     LogLevel level;
@@ -344,6 +370,7 @@ typedef struct LogEntry{
 } LogEntry;
 extern LogEntry* LogFirst;
 extern LogEntry* LogLast;
+extern int logcount;
 typedef void (*LogListener)(LogEntry*);
 #define MAX_LOGS 200
 #define LOG_APPEND(_Entry) if (LogLast) {\
@@ -363,7 +390,7 @@ typedef void (*LogListener)(LogEntry*);
 #define LOG_SETMESSAGE(_Entry,_msg) free(_Entry->message);_Entry->message=strdup(_msg)
 #define LOG_SETORIGIN(_Entry,_orig) free(_Entry->origin);_Entry->origin=strdup(_orig)
 
-typedef struct{
+typedef struct PipeLog {
     char* name;
     LogLevel level;
     int log; /*yes or no to log*/
@@ -467,14 +494,20 @@ typedef struct Cache_Entry {
 #define RI_IMAGE_SUMS	    0x2
 extern int  replyinfo_status, requestinfo_sent, replyinfo_last_face;
 
-typedef struct
-{
+typedef struct PlayerPosition {
   int x;
   int y;
 } PlayerPosition;
 
 extern PlayerPosition pl_pos;
 
+
+typedef struct Msg_Type_Names {
+    int        type;           /* type of message */
+    int        subtype;        /* subtype of message */
+    const char *style_name;    /* name of this message in the configfile */
+} Msg_Type_Names;
+
 extern TextManager* firstTextManager;
 
 #ifndef MIN
