@@ -1,5 +1,5 @@
-const char *rcsid_common_commands_c =
-    "$Id: commands.c 8075 2008-01-03 11:43:29Z ryo_saeba $";
+const char * const rcsid_common_commands_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -213,8 +213,13 @@ void SetupCmd(char *buf, int len) {
          * returns to us.  In some cases, we may fall back to other
          * methods, just report on error, or try another setup command.
          */
-        if (!strcmp(cmd, "sound")) {
-            if (!strcmp(param, "FALSE")) {
+        if (!strcmp(cmd, "sound2")) {
+            /* No parsing needed, but we don't want a warning about unknown
+             * setup option below.
+             */
+        } else if (!strcmp(cmd, "sound")) {
+            /* No, this should not be !strcmp()... */
+            if (strcmp(param, "FALSE")) {
                 cs_print_string(csocket.fd, "setsound %d", want_config[CONFIG_SOUND]);
             }
         } else if (!strcmp(cmd, "mapsize")) {
@@ -247,7 +252,7 @@ void SetupCmd(char *buf, int len) {
                 mapdata_set_size(use_config[CONFIG_MAPWIDTH], use_config[CONFIG_MAPHEIGHT]);
                 cs_print_string(csocket.fd,
                                 "setup mapsize %dx%d", use_config[CONFIG_MAPWIDTH], use_config[CONFIG_MAPHEIGHT]);
-                sprintf(tmpbuf, "Server supports a max mapsize of %d x %d - requesting a %d x %d mapsize",
+                snprintf(tmpbuf, sizeof(tmpbuf), "Server supports a max mapsize of %d x %d - requesting a %d x %d mapsize",
                     x, y, use_config[CONFIG_MAPWIDTH], use_config[CONFIG_MAPHEIGHT]);
                 draw_info(tmpbuf, NDI_RED);
             } else if (use_config[CONFIG_MAPWIDTH] == x && use_config[CONFIG_MAPHEIGHT] == y) {
@@ -258,7 +263,7 @@ void SetupCmd(char *buf, int len) {
                  * not the same size, so whats the problem?  Tell the user that
                  * something is wrong.
                  */
-                sprintf(tmpbuf, "Unable to set mapsize on server - we wanted %d x %d, server returned %d x %d",
+                snprintf(tmpbuf, sizeof(tmpbuf), "Unable to set mapsize on server - we wanted %d x %d, server returned %d x %d",
                     use_config[CONFIG_MAPWIDTH], use_config[CONFIG_MAPHEIGHT], x, y);
                 draw_info(tmpbuf, NDI_RED);
             }
@@ -308,12 +313,8 @@ void SetupCmd(char *buf, int len) {
              */
         } else if (!strcmp(cmd, "exp64")) {
             /* If this server does not support the new skill code,
-             * fall back to the old which uses experience categories.
-             * for that, initialize the skill names appropriately.
-             * by doing so, the actual display code can be the same
-             * for both old and new.  If the server does support
-             * new exp system, send a request to get the mapping
-             * information.
+             * error out. If the server does support new exp system,
+             * send a request to get the mapping information.
              */
             if (!strcmp(param, "FALSE")) {
                 draw_info("Server does not support exp64!", NDI_RED);
@@ -352,6 +353,8 @@ void SetupCmd(char *buf, int len) {
                     manager = manager->next;
                 }
             }
+        } else if (!strcmp(cmd, "want_pickup")) {
+            /* Nothing to do specially, it's info pushed from server, not having it isn't that bad. */
         } else if (!strcmp(cmd, "inscribe")) {
             if (strcmp(param, "FALSE"))
                 command_inscribe = atoi(param);
@@ -565,6 +568,31 @@ void DrawExtInfoCmd(char *data, int len) {
     fnct(color, type, subtype, buf);
 }
 
+/* Maintain the last_used_skills LRU list for displaying the recently used
+ * skills first. */
+void use_skill(int skill_id)
+{
+   int i = 0;
+   int next;
+   int prev = last_used_skills[0];
+   /*
+   char buf[100];
+   sprintf(buf, "use_skill(%d '%s')\n", skill_id, skill_names(skill_id));
+   draw_info(, NDI_BLUE);
+   */
+
+   if(last_used_skills[0] == skill_id) return;
+
+   do
+   {
+	  next = last_used_skills[i+1];
+	  last_used_skills[i+1] = prev;
+	  prev = next;
+	  ++i;
+   } while(next != skill_id && next >= 0);
+   last_used_skills[0] = skill_id;
+}
+
 void StatsCmd(unsigned char *data, int len) {
     int i = 0, c, redraw = 0;
     sint64 last_exp;
@@ -587,6 +615,7 @@ void StatsCmd(unsigned char *data, int len) {
             cpl.stats.skill_level[c-CS_STAT_SKILLINFO] = data[i++];
             last_exp = cpl.stats.skill_exp[c-CS_STAT_SKILLINFO];
             cpl.stats.skill_exp[c-CS_STAT_SKILLINFO] = GetInt64_String(data+i);
+			use_skill(c-CS_STAT_SKILLINFO);
             if (last_exp == 0 && cpl.stats.skill_exp[c-CS_STAT_SKILLINFO]) {
                 redraw = 1;
             }
@@ -633,8 +662,12 @@ void StatsCmd(unsigned char *data, int len) {
             case CS_STAT_SKILLEXP_PHYSIQUE:
             case CS_STAT_SKILLEXP_MAGIC:
             case CS_STAT_SKILLEXP_WISDOM:
-                cpl.stats.skill_exp[(c-CS_STAT_SKILLEXP_START)/2] = GetInt_String(data+i);
+				  {
+					 int skill_id = (c-CS_STAT_SKILLEXP_START)/2;
+				   cpl.stats.skill_exp[skill_id] = GetInt_String(data+i);
+				   use_skill(skill_id);
                 i += 4;
+				  }
                 break;
 
             case CS_STAT_SKILLEXP_AGLEVEL:
@@ -676,6 +709,9 @@ void StatsCmd(unsigned char *data, int len) {
     }
     draw_stats(redraw);
     draw_message_window(0);
+#ifdef HAVE_LUA
+    script_lua_stats();
+#endif
 }
 
 void handle_query(char *data, int len) {
@@ -1351,3 +1387,16 @@ void TickCmd(uint8 *data, int len) {
     /* Up to the specific client to decide what to do */
     client_tick(tick);
 }
+
+/**
+ * Server gives us current player's pickup.
+ *
+ * @param data
+ * buffer sent by server.
+ * @param len
+ * length of data.
+ */
+void PickupCmd(uint8 *data, int len) {
+    uint32 pickup = GetInt_String(data);
+    client_pickup(pickup);
+}
