@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_external_h =
- *   "$Id: external.h 4963 2006-09-21 05:50:22Z mwedel $";
+ *   "$Id$";
  */
 /*
     Crossfire client, a client program for the crossfire program.
@@ -33,7 +33,9 @@
  */
 
 /* Sound functions */
-extern void SoundCmd(unsigned char *data,  int len);
+extern void SoundCmd(unsigned char *data, int len);
+extern void Sound2Cmd(unsigned char *data, int len);
+extern void MusicCmd(const char *data, int len);
 
 /* Map window related functions */
 extern void resize_map_window(int x, int y);
@@ -88,3 +90,4 @@ extern void save_defaults(void);
 extern void command_show(const char *params);
 extern void client_tick(uint32 tick);
 extern void cleanup_connection();
+extern void client_pickup(uint32 pickup);
