@@ -1,5 +1,5 @@
-const char *rcsid_common_init_c =
-    "$Id: init.c 7093 2007-09-01 05:51:19Z mwedel $";
+const char * const rcsid_common_init_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -26,9 +26,6 @@ const char *rcsid_common_init_c =
  * the I_IMAGE and I_ARCH commands.
  */
 
-#ifdef WIN32
-#define srandom(x) srand(x)
-#endif
 #include <client.h>
 #include "p_cmd.h" /* init_commands() */
 
@@ -97,11 +94,11 @@ void SendSetFaceMode(ClientSocket csock,int mode)
 }
 
 
-void init_client_vars()
+void init_client_vars(void)
 {
     int i;
 
-    /* I think environemental variables should be more important than
+    /* I think environment variables should be more important than
      * compiled in defaults, so these probably should be reversed.
      */
     client_libdir=getenv("CFCLIENT_LIBDIR");
@@ -136,7 +133,9 @@ void init_client_vars()
 	cpl.stats.skill_exp[i]=0;
 	cpl.stats.skill_level[i] = 0;
 	skill_names[i] = NULL;
+	last_used_skills[i] = -1;
     }
+	last_used_skills[MAX_SKILL] = -1;
 
     cpl.ob = player_item();
     cpl.below = map_item();
@@ -213,7 +212,7 @@ void init_client_vars()
             {
             char env[ MAX_BUF ];
             _snprintf( env, MAX_BUF, "HOME=%s", getenv( "APPDATA" ) );
-            LOG( LOG_INFO, "common::inic.c", "init_client_vars: HOME set to %APPDATA%.\n" );
+            LOG( LOG_INFO, "common::init.c", "init_client_vars: HOME set to %APPDATA%.\n" );
             putenv( env );
             }
         else
@@ -232,7 +231,7 @@ void init_client_vars()
 /* This is basically called each time a new player logs
  * on - reset all the player data
  */
-void reset_player_data()
+void reset_player_data(void)
 {
     int i;
 
@@ -247,7 +246,7 @@ void reset_player_data()
  * been called because it does not re-allocated some values.
  */
 
-void reset_client_vars()
+void reset_client_vars(void)
 {
     int i;
 
