@@ -1,5 +1,5 @@
-const char *rcsid_common_metaserver_c =
-    "$Id: metaserver.c 8076 2008-01-03 11:47:41Z ryo_saeba $";
+const char * const rcsid_common_metaserver_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -37,12 +37,12 @@ const char *rcsid_common_metaserver_c =
 
 #include <ctype.h>
 #include <stdio.h>
+#include <stdlib.h>
 
 #include <client.h>
 #include <cconfig.h>
 #include <external.h>
 
-#include <pthread.h>
 #include <metaserver.h>
 
 #ifdef HAVE_CURL_CURL_H
@@ -77,11 +77,20 @@ int check_server_version(int entry)
 	/* 1027->1028 removed a bunch of old commands, so a 1028
 	 * version client can still play on a 1027 server, so
 	 * special hard code that.
+	 *
+	 * Likewise, 1028->1029 just changed how weapon_speed
+	 * should be interperted on the client - the client
+	 * does the right thing, so not problem with a 1029
+	 * client playing on 1028 or 1027 server.
+	 *
+	 * A 1028 client could in practice play on a 1029
+	 * server, since at the protocol level, data is the same -
+	 * the client would just have screwed up weapon_sp values.
 	 */
-	 /* This could perhaps get extended in the future, if other protocol
-	 * revision that maintain compatibility.
-	 */
-	if (VERSION_SC != 1028 && meta_servers[entry].sc_version != 1027) return 0;
+	if ((VERSION_SC == 1028 || VERSION_SC==1029) &&
+	    (meta_servers[entry].sc_version==1027 ||
+	     meta_servers[entry].sc_version==1028))
+	    return 1;
     }
     if (meta_servers[entry].cs_version != VERSION_CS) return 0;
 
@@ -209,7 +218,7 @@ size_t metaserver2_writer(void *ptr, size_t size, size_t nmemb, void *data)
     char    *cp, *newline, *eq, inbuf[CURL_MAX_WRITE_SIZE*2+1], *leftover;
 
     leftover = (char*) data;
-    
+
     if (realsize > CURL_MAX_WRITE_SIZE) {
         LOG(LOG_CRITICAL, "common::metaserver2_writer", "Function called with more data than allowed!");
     }
@@ -391,8 +400,6 @@ void *metaserver2_thread(void *junk)
 
     do {
 	metaserver_choice = random() % (sizeof(metaservers) / sizeof(char*));
-
-        fprintf(stderr,"Choosing server %d\n", metaserver_choice);
     } while (!get_metaserver2_data(metaservers[metaserver_choice]));
 
     pthread_mutex_lock(&ms2_info_mutex);
@@ -400,6 +407,8 @@ void *metaserver2_thread(void *junk)
     ms2_is_running=0;
     pthread_mutex_unlock(&ms2_info_mutex);
     pthread_exit(NULL);
+    // never reached, just to make the compiler happy.
+    return NULL;
 }
 
 
@@ -411,7 +420,7 @@ void *metaserver2_thread(void *junk)
  * @return
  * best I can tell, always returns 0
  */
-int metaserver2_get_info() {
+int metaserver2_get_info(void) {
     pthread_t   thread_id;
     int	    ret;
 
@@ -426,7 +435,7 @@ int metaserver2_get_info() {
 
     pthread_mutex_lock(&ms2_info_mutex);
     if (!meta_servers)
-        meta_servers = malloc(sizeof(Meta_Info)*MAX_METASERVER);
+        meta_servers = calloc(MAX_METASERVER, sizeof(Meta_Info));
 
     ms2_is_running=1;
     pthread_mutex_unlock(&ms2_info_mutex);
@@ -440,14 +449,14 @@ int metaserver2_get_info() {
     }
 
     return 0;
-}    
+}
 
 
 
 /**
  * Does single use initalization of metaserver2 variables.
  */
-void init_metaserver()
+void init_metaserver(void)
 {
     pthread_mutex_init(&ms2_info_mutex, NULL);
 #ifdef HAVE_CURL_CURL_H
@@ -496,9 +505,11 @@ char *get_line_from_sock(char *s, size_t n, int fd) {
 
     /* If there is no line in the buffer */
     while (charsleft == 0 || (cp = strchr(inbuf, '\n')) == NULL) {
-        FD_SET fdset = {1, fd};
+        FD_SET fdset;
         TIMEVAL tv = {3, 0}; /* 3 second timeout on reads */
         int nlen;
+        FD_ZERO(&fdset);
+        FD_SET(fd, &fdset);
         if (select(0, &fdset, NULL, NULL, &tv) == 0) {
             draw_info("Metaserver timed out.", NDI_BLACK);
             return NULL;
@@ -602,7 +613,7 @@ void *metaserver1_thread(void *junk)
 
     pthread_mutex_lock(&ms2_info_mutex);
     if (!meta_servers)
-        meta_servers = malloc(sizeof(Meta_Info)*MAX_METASERVER);
+        meta_servers = calloc(MAX_METASERVER, sizeof(Meta_Info));
 
 
     /* The loop goes through and unpacks the data from the metaserver
@@ -710,10 +721,12 @@ void *metaserver1_thread(void *junk)
     ms1_is_running=0;
     pthread_mutex_unlock(&ms2_info_mutex);
     pthread_exit(NULL);
+    // never reached, just to make the compiler happy.
+    return NULL;
 }
 
 
-int metaserver1_get_info() {
+int metaserver1_get_info(void) {
     pthread_t   thread_id;
     int	    ret;
 
@@ -724,7 +737,7 @@ int metaserver1_get_info() {
 
     pthread_mutex_lock(&ms2_info_mutex);
     if (!meta_servers)
-        meta_servers = malloc(sizeof(Meta_Info)*MAX_METASERVER);
+        meta_servers = calloc(MAX_METASERVER, sizeof(Meta_Info));
 
     ms1_is_running=1;
     pthread_mutex_unlock(&ms2_info_mutex);
@@ -738,7 +751,7 @@ int metaserver1_get_info() {
     }
 
     return 0;
-}    
+}
 /******************************************************************************
  * End of metaserver1 logic
  ******************************************************************************/
@@ -758,7 +771,7 @@ int metaserver1_get_info() {
  * @return
  * Returns 1 if if we are getting data, 0 if nothing is going on right now.
  */
-int metaserver_check_status() {
+int metaserver_check_status(void) {
     int status;
 
     pthread_mutex_lock(&ms2_info_mutex);
@@ -798,7 +811,7 @@ void metaserver_show(int show_selection) {
     if (cached_servers_num) {
         draw_info("\nLast servers you connected to:\n", NDI_BLACK);
         for (i = 0; i < cached_servers_num; i++) {
-            sprintf(buf, "%2d) %-20.20s %-20.20s", i+1, cached_servers_name[i], cached_servers_ip[i]);
+            snprintf(buf, sizeof(buf), "%2d) %-20.20s %-20.20s", i+1, cached_servers_name[i], cached_servers_ip[i]);
             draw_info(buf, NDI_BLACK);
         }
         draw_info(" ", NDI_BLACK);
@@ -812,13 +825,13 @@ void metaserver_show(int show_selection) {
     draw_info("         Name      players           seconds", NDI_BLACK);
     pthread_mutex_lock(&ms2_info_mutex);
 
-    /* Re-sort the data - may get different data from ms1 and ms2, so 
+    /* Re-sort the data - may get different data from ms1 and ms2, so
      * order of this is somewhat random.
      */
     qsort(meta_servers, meta_numservers, sizeof(Meta_Info), (int (*)(const void *, const void *))meta_sort);
     for (i = 0; i < meta_numservers; i++) {
 	if (check_server_version(i)) {
-	    sprintf(buf, "%2d)  %-15.15s %2d   %-12.12s %2d",
+	    snprintf(buf, sizeof(buf), "%2d)  %-15.15s %2d   %-12.12s %2d",
 		    i+1+cached_servers_num, meta_servers[i].hostname,
 		    meta_servers[i].num_players, meta_servers[i].version,
 		    meta_servers[i].idle_time);
@@ -828,7 +841,7 @@ void metaserver_show(int show_selection) {
     if (show_selection) {
         /* Show default/current server */
 	if (server) {
-	    sprintf(buf, "%2d)  %s (default)", meta_numservers+1+cached_servers_num, server);
+	    snprintf(buf, sizeof(buf), "%2d)  %s (default)", meta_numservers+1+cached_servers_num, server);
 	    draw_info(buf, NDI_BLACK);
 	}
 
@@ -913,7 +926,7 @@ int metaserver_select(char *sel) {
 	}
     }
 
-    sprintf(buf, "Trying to connect to %s:%d", server_name, port);
+    snprintf(buf, sizeof(buf), "Trying to connect to %s:%d", server_name, port);
     draw_info(buf, NDI_BLACK);
 #ifdef MULTKEYS
     csocket.fd = init_connection(server_name, port);
@@ -1001,7 +1014,7 @@ int main(int argc, char *argv[])
  * in just causes more dependencies, etc.
  */
 void draw_info(const char *str, int color) { }
-int init_connection(char *host, int port) {} 
+int init_connection(char *host, int port) {}
 
 int metaserver_on=1, meta_port=0;
 char *server=NULL, *meta_server;
