@@ -1,5 +1,5 @@
-const char *rcsid_common_misc_c =
-    "$Id: misc.c 7552 2007-11-20 20:44:54Z tchize $";
+const char * const rcsid_common_misc_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -24,7 +24,7 @@ const char *rcsid_common_misc_c =
 
 /*
  * static char *rcsid_misc_c =
- *   "$Id: misc.c 7552 2007-11-20 20:44:54Z tchize $";
+ *   "$Id$";
  */
 
 
@@ -104,10 +104,12 @@ int make_path_to_file (char *filename)
 	if (stat (buf, &statbuf) || !S_ISDIR (statbuf.st_mode)) {
 #ifdef WIN32
 	    if (mkdir (buf)) {
+                LOG(LOG_ERROR, "misc.c::make_path_to_file",
+                    "Couldn't make path to file: %s", strerror(errno));
 #else
 	    if (mkdir (buf, 0777)) {
-#endif
 		perror ("Couldn't make path to file");
+#endif
 		return -1;
 	    }
 	}
@@ -130,8 +132,8 @@ char *strdup_local(const char *str) {
 /* logging stuff */
 LogEntry* LogFirst=NULL;
 LogEntry* LogLast=NULL;
-LogListener loglist=NULL;
 int logcount=0;
+LogListener loglist=NULL;
 int setLogListener(LogListener li){
     if (loglist)
         return 0;
@@ -155,7 +157,7 @@ static const char *getLogLevelText(LogLevel level) {
 char *getLogTextRaw(LogLevel level, const char *origin, const char *message) {
     static char mybuf[20480];
     mybuf[0]='\0';
-    sprintf(mybuf,"[%s] (%s) %s\n",getLogLevelText(level),origin,message);
+    snprintf(mybuf, sizeof(mybuf), "[%s] (%s) %s\n",getLogLevelText(level),origin,message);
     return mybuf;
 }
 
@@ -187,7 +189,7 @@ void LOG(LogLevel level, const char *origin, const char *format, ...)
   va_start(ap, format);
 
   buf[0] = '\0';
-  vsprintf(buf, format, ap);
+  vsnprintf(buf, sizeof(buf), format, ap);
   /*fprintf(stderr,getLogTextRaw(level,origin,buf));*/
   if (strlen(buf)>0){
     LogEntry *le = LOG_NEW_ENTRY;
@@ -272,7 +274,7 @@ void logPipe(ChildProcess *child, LogLevel level, int pipe){
     if ( (pipe<1) || (pipe>2))/*can't log stdin as it's write only*/
         return;
     if (!child->logger[pipe].name){
-        sprintf(buf,"Child%d::%s::%d",child->pid,child->name?child->name:"NONAME",pipe);
+        snprintf(buf, sizeof(buf), "Child%d::%s::%d",child->pid,child->name?child->name:"NONAME",pipe);
         child->logger[pipe].name=strdup(buf);
     }
     if (fcntl(child->tube[pipe], F_SETFL, O_NDELAY)==-1) {
