@@ -230,7 +230,7 @@ static void do_serverhelp(const char * arg) {
 
     if (arg) {
         char buf[MAX_BUF];
-	sprintf(buf,"help %s", arg);
+	snprintf(buf, sizeof(buf), "help %s", arg);
 	/* maybe not a must send, but we probably don't want to drop it */
 	send_command(buf, -1, 1);
     } else {
@@ -263,7 +263,7 @@ static void command_help(const char *cpnext) {
         if (cc != NULL) {
             show_help(cc);
         } else  {
-	    sprintf(buf,"help %s", cpnext);
+	    snprintf(buf, sizeof(buf), "help %s", cpnext);
 	    /* maybe not a must send, but we probably don't want to drop it */
 	    send_command(buf, -1, 1);
 	}
@@ -401,17 +401,6 @@ static void do_metaserver(const char * ignored) {
             draw_info("Unable to get metaserver information.", NDI_BLACK);
 }
 
-static void do_resist(const char * ignored) {
-        /* For debugging only */
-        int i;
-        char buf[256];
-        for (i=0; i<NUM_RESISTS; i++) {
-            sprintf(buf,"%-20s %+4d",
-                    resists_name[i], cpl.stats.resists[i]);
-            draw_info(buf, NDI_BLACK);
-        }
-}
-
 static void do_savedefaults(const char * ignored) { save_defaults(); }
 
 static void do_savewinpos(const char * ignored) { save_winpos(); }
@@ -567,7 +556,19 @@ static ConsoleCommand CommonCommands[] = {
         script_init, help_script,
         NULL
     },
+#ifdef HAVE_LUA
+    {   "lua_load", COMM_CAT_SCRIPT,
+    script_lua_load, NULL, NULL
+    },
 
+    {   "lua_list", COMM_CAT_SCRIPT,
+    script_lua_list, NULL, NULL
+    },
+
+    {   "lua_kill", COMM_CAT_SCRIPT,
+    script_lua_kill, NULL, NULL
+    },
+#endif
     {
         "scripts", COMM_CAT_SCRIPT,
         do_script_list, NULL,
@@ -656,12 +657,6 @@ static ConsoleCommand CommonCommands[] = {
         "Print 'metaserver information'. Warning - your client will pause."
     },
 
-    {
-        "resist", COMM_CAT_DEBUG,
-        do_resist, NULL,
-	"Print resistances"
-    },
-
     {
         "savedefaults", COMM_CAT_SETUP,
         do_savedefaults, NULL,
@@ -913,6 +908,10 @@ void extended_command(const char *ocommand) {
      * and cpnext contains everything after that first space.  cpnext
      * could be NULL.
      */
+#ifdef HAVE_LUA
+    if ( script_lua_command(cp, cpnext) )
+        return;
+#endif
 
     /* If this isn't a client-side command, send it to the server. */
     if (!handle_local_command(cp, cpnext)) {
@@ -972,14 +971,18 @@ static const char *const commands[] = {
 
 const char * complete_command(const char *command)
 {
-    int i, len;
+    int i, len, display;
     const char *match;
     static char result[64];
+    char list[500];
 
     len = strlen(command);
 
     if (len == 0)
-	return NULL;
+        return NULL;
+
+    display = 0;
+    strcpy(list, "Matching commands:");
 
     /* TODO Partial match, e.g.:
          If the completion list was:
@@ -995,29 +998,39 @@ const char * complete_command(const char *command)
 
     /* check server side commands */
     for (i=0; i<NUM_COMMANDS; i++) {
-	if (!strncmp(command, commands[i], len)) {
-            if (match != NULL) {
-                /* The current prefix is ambiguous; leave it as is. */
-                return NULL;
-            }
-
-	    match = commands[i];
-	}
+        if (!strncmp(command, commands[i], len)) {
+            if (display) {
+                snprintf(list + strlen(list), 499 - strlen(list), " %s", commands[i]);
+            } else if (match != NULL) {
+                display = 1;
+                snprintf(list + strlen(list), 499 - strlen(list), " %s %s", match, commands[i]);
+                match = NULL;
+            } else
+                match = commands[i];
+        }
     }
 
     /* check client side commands */
     for (i=0; i<CommonCommandsSize; i++) {
-	if (!strncmp(command, CommonCommands[i].name, len)) {
-            if (match != NULL) {
-                /* The current prefix is ambiguous; leave it as is. */
-                return NULL;
-            }
-
-	    match = CommonCommands[i].name;
-	}
+        if (!strncmp(command, CommonCommands[i].name, len)) {
+            if (display) {
+                snprintf(list + strlen(list), 499 - strlen(list), " %s", CommonCommands[i].name);
+            } else if (match != NULL) {
+                display = 1;
+                snprintf(list + strlen(list), 499 - strlen(list), " %s %s", match, CommonCommands[i].name);
+                match = NULL;
+            } else
+                match = CommonCommands[i].name;
+        }
     }
 
     if (match == NULL) {
+        if (display) {
+            strncat(list, "\n", 499 - strlen(list));
+            draw_info(list, NDI_BLACK);
+        }
+        else
+            draw_info("No matching command.\n", NDI_BLACK);
         /* No match. */
         return NULL;
     }
