@@ -1,5 +1,5 @@
-const char *rcsid_common_player_c =
-    "$Id: player.c 8075 2008-01-03 11:43:29Z ryo_saeba $";
+const char * const rcsid_common_player_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -113,13 +113,13 @@ static int drun=-1, dfire=-1;
  * case - the fire is centered on the player.
  */
 
-void stop_fire()
+void stop_fire(void)
 {
     if (cpl.input_state != Playing) return;
     dfire |= 0x100;
 }
 
-void clear_fire_run()
+void clear_fire_run(void)
 {
     if ((dfire!=-1) && (dfire & 0x100)) {
 	send_command("fire_stop", -1, SC_FIRERUN);
@@ -131,7 +131,7 @@ void clear_fire_run()
     }
 }
 
-void clear_fire()
+void clear_fire(void)
 {
     if (dfire!=-1) {
 	send_command("fire_stop", -1, SC_FIRERUN);
@@ -139,7 +139,7 @@ void clear_fire()
     }
 }
 
-void clear_run()
+void clear_run(void)
 {
     if (drun!=-1) {
 	send_command("run_stop", -1, SC_FIRERUN);
@@ -153,7 +153,7 @@ void fire_dir(int dir) {
 
     if (cpl.input_state != Playing) return;
     if (dir!= dfire) {
-	sprintf(buf,"fire %d", dir);
+	snprintf(buf, sizeof(buf), "fire %d", dir);
 	if (send_command(buf, cpl.count, SC_NORMAL)) {
 	    dfire=dir;
 	    cpl.count=0;
@@ -163,7 +163,7 @@ void fire_dir(int dir) {
     }
 }
 
-void stop_run()
+void stop_run(void)
 {
     send_command("run_stop", -1, SC_FIRERUN);
     drun |= 0x100;
@@ -173,7 +173,7 @@ void run_dir(int dir) {
     char buf[MAX_BUF];
 
     if (dir!=drun) {
-	sprintf(buf,"run %d", dir);
+	snprintf(buf, sizeof(buf), "run %d", dir);
 	if (send_command(buf, -1, SC_NORMAL))
 	    drun=dir;
     } else {
