@@ -14,6 +14,7 @@ void SmoothCmd(unsigned char *data, int len);
 void DrawInfoCmd(char *data, int len);
 void setTextManager(int type, ExtTextManager callback);
 void DrawExtInfoCmd(char *data, int len);
+void use_skill(int skill_id);
 void StatsCmd(unsigned char *data, int len);
 void handle_query(char *data, int len);
 void send_reply(const char *text);
@@ -34,6 +35,7 @@ void MapExtendedCmd(unsigned char *data, int len);
 void MagicMapCmd(unsigned char *data, int len);
 void SinkCmd(unsigned char *data, int len);
 void TickCmd(uint8 *data, int len);
+void PickupCmd(uint8 *data, int len);
 /* image.c */
 void init_common_cache_data(void);
 void requestface(int pnum, char *facename);
@@ -55,7 +57,7 @@ void reset_client_vars(void);
 /* item.c */
 uint8 get_type_from_name(const char *name);
 void update_item_sort(item *it);
-char *get_number(uint32 i);
+const char *get_number(uint32 i);
 void free_all_items(item *op);
 item *locate_item(sint32 tag);
 void remove_item(item *op);
@@ -91,6 +93,7 @@ sint16 mapdata_bigface(int x, int y, int layer, int *ww, int *hh);
 sint16 mapdata_bigface_head(int x, int y, int layer, int *ww, int *hh);
 void mapdata_animation(void);
 /* metaserver.c */
+int check_server_version(int entry);
 size_t metaserver2_writer(void *ptr, size_t size, size_t nmemb, void *data);
 void *metaserver2_thread(void *junk);
 int metaserver2_get_info(void);
@@ -147,3 +150,9 @@ int send_command(const char *command, int repeat, int must_send);
 void CompleteCmd(unsigned char *data, int len);
 void command_take(const char *command, const char *cpnext);
 /* script.c */
+/* script_lua.c */
+void script_lua_load(const char *name);
+void script_lua_list(const char *param);
+void script_lua_kill(const char *param);
+void script_lua_stats(void);
+int script_lua_command(const char *command, const char *param);
