@@ -2,6 +2,7 @@
 extern void menu_about(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_about_close_clicked(GtkButton *button, gpointer user_data);
 /* config.c */
+extern void load_theme(int reload);
 extern void load_defaults(void);
 extern void save_defaults(void);
 extern void config_init(GtkWidget *window_root);
@@ -21,24 +22,26 @@ extern void image_update_download_status(int start, int end, int total);
 extern void get_map_image_size(int face, uint8 *w, uint8 *h);
 extern void init_cache_data(void);
 /* info.c */
+extern void set_text_tag_from_style(GtkTextTag *tag, GtkStyle *style, GtkStyle *base_style);
+extern void info_get_styles(void);
 extern void info_init(GtkWidget *window_root);
 extern void draw_info(const char *str, int color);
 extern void draw_color_info(int colr, const char *buf);
 extern void menu_clear(void);
-extern void set_scroll(char *s);
-extern void set_autorepeat(char *s);
+extern void set_scroll(const char *s);
+extern void set_autorepeat(const char *s);
 extern int get_info_width(void);
 /* inventory.c */
 extern gboolean list_selection_func(GtkTreeSelection *selection, GtkTreeModel *model, GtkTreePath *path, gboolean path_currently_selected, gpointer userdata);
 extern void list_row_collapse(GtkTreeView *treeview, GtkTreeIter *iter, GtkTreePath *path, gpointer user_data);
+extern void inventory_get_styles(void);
 extern void inventory_init(GtkWidget *window_root);
-extern void set_show_icon(char *s);
-extern void set_show_weight(char *s);
+extern void set_show_icon(const char *s);
+extern void set_show_weight(const char *s);
 extern void close_container(item *op);
 extern void open_container(item *op);
-extern void command_show(char *params);
+extern void command_show(const char *params);
 extern void set_weight_limit(uint32 wlim);
-extern void get_row_color(item *it, int *fg, int *bg);
 extern void item_event_item_deleting(item *it);
 extern void item_event_container_clearing(item *container);
 extern void item_event_item_changed(item *it);
@@ -52,11 +55,12 @@ extern void draw_lists(void);
 extern void on_notebook_switch_page(GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data);
 extern gboolean on_inv_table_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer user_data);
 extern void animate_inventory(void);
+extern void animate_look(void);
 extern void inventory_tick(void);
 /* keys.c */
 extern void keys_init(GtkWidget *window_root);
 extern void bind_key(char *params);
-extern void unbind_key(char *params);
+extern void unbind_key(const char *params);
 extern void keyrelfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window);
 extern void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window);
 extern void draw_keybindings(GtkWidget *keylist);
@@ -93,6 +97,7 @@ extern void drawsmooth(int mx, int my, int layer, int picx, int picy);
 extern void gtk_draw_map(int redraw);
 extern void display_map_newmap(void);
 extern void resize_map_window(int x, int y);
+extern gboolean on_drawingarea_map_configure_event(GtkWidget *widget, GdkEventConfigure *event, gpointer user_data);
 extern void draw_splash(void);
 extern void draw_map(int redraw);
 extern gboolean on_drawingarea_map_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer user_data);
@@ -104,7 +109,6 @@ extern void draw_magic_map(void);
 extern void magic_map_flash_pos(void);
 extern gboolean on_drawingarea_magic_map_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer user_data);
 /* menubar.c */
-extern void on_disconnect_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void menu_quit_program(GtkMenuItem *menuitem, gpointer user_data);
 extern void menu_quit_character(GtkMenuItem *menuitem, gpointer user_data);
 extern void enable_menu_items(int enable);
@@ -142,9 +146,9 @@ extern void on_menu_magical_items_activate(GtkMenuItem *menuitem, gpointer user_
 extern void on_menu_potions_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_valuables_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_wands_rods_horns_activate(GtkMenuItem *menuitem, gpointer user_data);
+extern void on_menu_not_cursed_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_jewels_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_flesh_activate(GtkMenuItem *menuitem, gpointer user_data);
-extern void on_menu_not_cursed_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_all_weapons_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_missile_weapons_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_bows_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -160,6 +164,8 @@ extern void on_menu_ratio_35_activate(GtkMenuItem *menuitem, gpointer user_data)
 extern void on_menu_ratio_40_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_ratio_45_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_ratio_50_activate(GtkMenuItem *menuitem, gpointer user_data);
+extern void pickup_init(GtkWidget *window_root);
+extern void client_pickup(uint32 pickup);
 /* png.c */
 extern uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height);
 extern uint8 *rescale_rgba_data(uint8 *data, int *width, int *height, int scale);
@@ -172,10 +178,12 @@ extern void drawquarterlightmap_sdl(int tl, int tr, int bl, int br, int width, i
 extern void sdl_gen_map(int redraw);
 extern int sdl_mapscroll(int dx, int dy);
 /* sound.c */
-extern void signal_pipe(int i);
 extern int init_sounds(void);
 extern void SoundCmd(unsigned char *data, int len);
+extern void Sound2Cmd(unsigned char *data, int len);
+extern void MusicCmd(const char *data, int len);
 /* spells.c */
+extern void spell_get_styles(void);
 extern void update_spell_information(void);
 extern void on_spells_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_spell_treeview_row_activated(GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
@@ -183,8 +191,9 @@ extern void on_spell_cast_clicked(GtkButton *button, gpointer user_data);
 extern void on_spell_invoke_clicked(GtkButton *button, gpointer user_data);
 extern void on_spell_close_clicked(GtkButton *button, gpointer user_data);
 /* stats.c */
+extern void stats_get_styles(void);
 extern void stats_init(GtkWidget *window_root);
-extern void update_stat(int stat_no, int max_stat, int current_stat, const char *name, int can_alert);
+extern void update_stat(int stat_no, sint64 max_stat, sint64 current_stat, sint64 statbar_max, sint64 statbar_stat, const char *name, int can_alert);
 extern void draw_message_window(int redraw);
 extern void draw_stats(int redraw);
 extern void clear_stat_mapping(void);
