@@ -1,6 +1,6 @@
 /*
  * char *rcsid_gtk2_main_h =
- *   "$Id: main.h 3187 2005-04-06 06:55:16Z mwedel $";
+ *   "$Id$";
  */
 /*
     Crossfire client, a client program for the crossfire program.
@@ -24,13 +24,22 @@
     The author can be reached via e-mail to crossfire@metalforge.org
 */
 
+/**
+ * @file gtk-v2/src/main.h
+ * Contains various global definitions and XML file name and path defaults.
+ */
+
 #define NUM_COLORS 13
 extern GdkColor root_color[NUM_COLORS];
-GtkWidget *window_root, *spinbutton_count;
+extern GtkWidget *window_root, *spinbutton_count;
+extern GladeXML *dialog_xml, *window_xml;
 
 #define DEFAULT_IMAGE_SIZE      32
 extern int map_image_size, map_image_half_size, image_size;
 
+#define XML_PATH_DEFAULT CF_DATADIR "/glade-gtk2/"
+#define WINDOW_XML_FILENAME "gtk-v2.glade"
+#define DIALOG_XML_FILENAME "dialogs.glade"
+extern char window_xml_file[];
 
-/* Notebook page of the magic map */
-#define MAGIC_MAP_PAGE	1
+#define MAGIC_MAP_PAGE  1 /**< Notebook page of the magic map */
