@@ -1,5 +1,5 @@
-const char *rcsid_gtk_config_c =
-    "$Id: config.c 6716 2007-06-27 18:57:31Z akirschbaum $";
+const char * const rcsid_gtk_config_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -216,7 +216,7 @@ static void set_config_value(int cval, int value)
 
 static int splitwin_toggling = FALSE;
 
-void main_window_destroyed() {
+void main_window_destroyed(void) {
     if (!splitwin_toggling) {
         client_exit();
     }
@@ -860,9 +860,9 @@ void save_defaults(void)
 	LOG(LOG_ERROR,"gtk::save_defaults","Could not open %s", path);
 	return;
     }
-    fprintf(fp,"# This file is generated automatically by gcfclient.\n");
-    fprintf(fp,"# Manually editing is allowed, however gcfclient may be a bit finicky about\n");
-    fprintf(fp,"# some of the matching it does.  all comparisons are case sensitive.\n");
+    fprintf(fp,"# This file is generated automatically by crossfire-client-gtk.\n");
+    fprintf(fp,"# Manual editing is allowed, but the client may be finicky about\n");
+    fprintf(fp,"# some of the matching it does.  All comparisons are case sensitive.\n");
     fprintf(fp,"# 'True' and 'False' are the proper cases for those two values\n");
     fprintf(fp,"# 'True' and 'False' have been replaced with 1 and 0 respectively\n");
     fprintf(fp,"server: %s\n", server);
