@@ -1,5 +1,5 @@
-const char *rcsid_gtk_image_c =
-    "$Id: image.c 6716 2007-06-27 18:57:31Z akirschbaum $";
+const char * const rcsid_gtk_image_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -96,8 +96,6 @@ static int icon_rescale_factor[MAX_ICON_SPACES] = {
  *
  *****************************************************************************/
 
-char facecachedir[MAX_BUF];
-
 typedef struct Keys {
     uint8	flags;
     sint8	direction;
@@ -386,7 +384,7 @@ int associate_cache_entry(Cache_Entry *ce, int pixnum)
  * or the like.
  */
 
-void reset_image_data()
+void reset_image_data(void)
 {
     int i;
     reset_image_cache_data();
