@@ -1,5 +1,5 @@
-const char *rcsid_gtk_keys_c =
-    "$Id: keys.c 6716 2007-06-27 18:57:31Z akirschbaum $";
+const char * const rcsid_gtk_keys_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -22,8 +22,10 @@ const char *rcsid_gtk_keys_c =
     The author can be reached via e-mail to crossfire-devel@real-time.com
 */
 
-/* This file handles most of the keyboard related functions - binding
- * and unbinding keys, and handling keypresses and looking up the
+/**
+ * @file gtk/keys.c
+ * Handles most of the GTK V1 client keyboard related functions.  This
+ * includes binding and unbinding keys, handling keypresses, and looking up the
  * keys.
  */
 
@@ -83,7 +85,7 @@ typedef struct Keys {
 
 
 static uint32 firekeysym[2], runkeysym[2], commandkeysym,*bind_keysym,
-    prevkeysym, nextkeysym, completekeysym;
+    prevkeysym, nextkeysym, completekeysym, cancelkeysym;
 static int bind_flags=0;
 static char bind_buf[MAX_BUF];
 
@@ -95,7 +97,7 @@ static char bind_buf[MAX_BUF];
 #define KEYF_EDIT	0x08	/* Line editor */
 #define KEYF_STANDARD	0x10	/* For standard (built in) key definitions */
 
-extern char *directions[9];
+extern const char * const directions[9];
 
 /* Platform independence defines that we can't use keycodes.
  * instead, make it a hash, and set KEYHASH to a prime number for
@@ -311,6 +313,7 @@ void init_keys(void)
     runkeysym[1]  =GDK_Control_R;
 
     completekeysym = GDK_Tab;
+    cancelkeysym = GDK_Escape;
 
     /* Don't set these to anything by default.  At least on sun
      * keyboards, the keysym for up on both the keypad and arrow
@@ -1001,21 +1004,33 @@ void keyrelfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window)
     }
 }
 
-
+extern void disconnect(GtkWidget*);
 void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
     char *text;
     updatelock=0;
 
     if (!use_config[CONFIG_POPUPS]) {
+        if ( ((cpl.input_state == Reply_One) || (cpl.input_state == Reply_Many))
+            && (event->keyval==cancelkeysym) ) {
+            /*Player hit cancel button during input. Disconnect it (code from menubar)*/
+                disconnect(widget);
+            return;
+        }
 	if  (cpl.input_state == Reply_One) {
 	    text=gdk_keyval_name(event->keyval);
 	    send_reply(text);
 	    cpl.input_state = Playing;
+            gtk_signal_emit_stop_by_name(GTK_OBJECT(window), "key_press_event");
 	    return;
 	}
 	else if (cpl.input_state == Reply_Many) {
-	    gtk_widget_grab_focus (GTK_WIDGET(entrytext));
-	    return;
+            if (GTK_WIDGET_HAS_FOCUS(entrytext)) {
+                gtk_widget_event(GTK_WIDGET(entrytext), (GdkEvent*)event);
+                gtk_signal_emit_stop_by_name(
+                    GTK_OBJECT(window), "key_press_event");
+            } else
+                gtk_widget_grab_focus(GTK_WIDGET(entrytext));
+            return;
 	}
     }
 
@@ -1023,12 +1038,16 @@ void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
     if (event->keyval<=0) return;
 
     if (GTK_WIDGET_HAS_FOCUS (entrytext) /*|| GTK_WIDGET_HAS_FOCUS(counttext)*/) {
-	if (event->keyval == completekeysym) gtk_complete_command();
+	if (event->keyval == completekeysym) {
+        gtk_complete_command();
+        return;
+    }
 	if (event->keyval == prevkeysym || event->keyval == nextkeysym)
 	    gtk_command_history(event->keyval==nextkeysym?0:1);
 #ifdef CFGTK2
     else
         gtk_widget_event(GTK_WIDGET(entrytext), (GdkEvent*)event);
+        gtk_signal_emit_stop_by_name(GTK_OBJECT(window), "key_press_event");
 #endif
     } else {
 	switch(cpl.input_state) {
@@ -1229,7 +1248,7 @@ void ckeyentry_callback (GtkWidget *widget, GdkEventKey *event, GtkWidget *windo
 }
 
 
-void ckeyclear () {
+void ckeyclear (void) {
   gtk_label_set (GTK_LABEL(cnumentrytext), "0");
   gtk_entry_set_text (GTK_ENTRY(ckeyentrytext), "Press key to bind here");
   /*  gtk_entry_set_text (GTK_ENTRY(cknumentrytext), ""); */
