@@ -1,5 +1,5 @@
-const char *rcsid_gtk_png_c =
-    "$Id: png.c 6716 2007-06-27 18:57:31Z akirschbaum $";
+const char * const rcsid_gtk_png_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
