@@ -1,5 +1,5 @@
-char *rcsid_gtk_text_c =
-    "$Id: text.c 7299 2007-10-04 07:15:13Z mwedel $";
+const char * const rcsid_gtk_text_c =
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
