@@ -1,5 +1,5 @@
 static char *rcsid_cfsndserv_c =
-    "$Id: cfsndserv.c 6716 2007-06-27 18:57:31Z akirschbaum $";
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -417,7 +417,7 @@ int init_audio(void){
   ioctl(soundfd, SNDCTL_DSP_STEREO, &stereo);
 
   frequency = settings.frequency;
-  if ( ioctl(soundfd, SOUND_PCM_WRITE_RATE, &frequency) < 0 ) {
+  if ( ioctl(soundfd, SNDCTL_DSP_SPEED, &frequency) < 0 ) {
           fprintf(stderr,"Couldn't set audio frequency\n");
           return(-1);
   }
@@ -1023,4 +1023,3 @@ int main(int argc, char *argv[])
 
     return 0;
 }
-
