@@ -1,5 +1,5 @@
 const char *rcsid_x11_xutil_c =
-    "$Id: xutil.c 6716 2007-06-27 18:57:31Z akirschbaum $";
+    "$Id$";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -45,7 +45,7 @@ const char *rcsid_x11_xutil_c =
 #include "x11.h"
 
 
-static const char *colorname[] = {
+static const char * const colorname[] = {
 "Black",                /* 0  */
 "White",                /* 1  */
 "Navy",                 /* 2  */
@@ -76,8 +76,6 @@ int use_private_cache=0, last_face_num=0;
  *
  *****************************************************************************/
 
-char facecachedir[MAX_BUF];
-
 typedef struct Keys {
     uint8	flags;
     sint8	direction;
@@ -113,7 +111,7 @@ static char bind_buf[MAX_BUF];
 #define KEYF_EDIT	0x08	/* Line editor */
 #define KEYF_STANDARD	0x10	/* For standard (built in) key definitions */
 
-extern char *directions[9];
+extern const char * const directions[9];
 
 /* Key codes can only be from 8-255 (at least according to
  * the X11 manual.  This is easier than using a hash
@@ -128,7 +126,7 @@ uint8 updatekeycodes=FALSE;
 
 #ifndef GDK_XUTIL
 /* Initializes the data for image caching */
-void init_cache_data()
+void init_cache_data(void)
 {
     int i;
     Pixmap  ptmp;
@@ -1184,7 +1182,7 @@ PlayerPosition pl_pos;
  * server versions.
  * @todo remove
  */
-void reset_map()
+void reset_map(void)
 {
 }
 
@@ -1197,3 +1195,10 @@ void addsmooth(uint16 face, uint16 smooth_face)
 void client_tick(uint32 tick)
 {
 }
+
+/**
+ * We get pickup information from server, update our status.
+ */
+void client_pickup(uint32 pickup)
+{
+}
